# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_dataset import ResourceListDataset

class TestResourceListDataset(unittest.TestCase):
    """ResourceListDataset unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListDataset:
        """Test ResourceListDataset
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListDataset`
        """
        model = ResourceListDataset()
        if include_optional:
            return ResourceListDataset(
                records = [
                    arthur_client.api_bindings.models.dataset.Dataset(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        name = '', 
                        dataset_locator = arthur_client.api_bindings.models.dataset_locator.DatasetLocator(
                            fields = [
                                arthur_client.api_bindings.models.dataset_locator_field.DatasetLocatorField(
                                    key = '', 
                                    value = '', )
                                ], ), 
                        dataset_schema = arthur_client.api_bindings.models.dataset_schema.DatasetSchema(
                            alias_mask = {
                                'key' : ''
                                }, 
                            columns = [
                                arthur_client.api_bindings.models.dataset_column.DatasetColumn(
                                    id = '', 
                                    source_name = '', 
                                    definition = null, )
                                ], 
                            column_names = {
                                'key' : ''
                                }, ), 
                        data_plane_id = '', 
                        connector = arthur_client.api_bindings.models.dataset_connector.DatasetConnector(
                            id = '', 
                            name = '', 
                            connector_type = 'shield', ), 
                        project_id = '', 
                        join_spec = arthur_client.api_bindings.models.dataset_join_spec.DatasetJoinSpec(
                            left_joined_dataset = arthur_client.api_bindings.models.joined_dataset.JoinedDataset(
                                id = '', 
                                name = '', 
                                column_id = '', 
                                column_name = '', ), 
                            right_joined_dataset = arthur_client.api_bindings.models.joined_dataset.JoinedDataset(
                                id = '', 
                                name = '', 
                                column_id = '', 
                                column_name = '', ), 
                            join_type = 'inner', ), 
                        model_problem_type = 'regression', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListDataset(
                records = [
                    arthur_client.api_bindings.models.dataset.Dataset(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        name = '', 
                        dataset_locator = arthur_client.api_bindings.models.dataset_locator.DatasetLocator(
                            fields = [
                                arthur_client.api_bindings.models.dataset_locator_field.DatasetLocatorField(
                                    key = '', 
                                    value = '', )
                                ], ), 
                        dataset_schema = arthur_client.api_bindings.models.dataset_schema.DatasetSchema(
                            alias_mask = {
                                'key' : ''
                                }, 
                            columns = [
                                arthur_client.api_bindings.models.dataset_column.DatasetColumn(
                                    id = '', 
                                    source_name = '', 
                                    definition = null, )
                                ], 
                            column_names = {
                                'key' : ''
                                }, ), 
                        data_plane_id = '', 
                        connector = arthur_client.api_bindings.models.dataset_connector.DatasetConnector(
                            id = '', 
                            name = '', 
                            connector_type = 'shield', ), 
                        project_id = '', 
                        join_spec = arthur_client.api_bindings.models.dataset_join_spec.DatasetJoinSpec(
                            left_joined_dataset = arthur_client.api_bindings.models.joined_dataset.JoinedDataset(
                                id = '', 
                                name = '', 
                                column_id = '', 
                                column_name = '', ), 
                            right_joined_dataset = arthur_client.api_bindings.models.joined_dataset.JoinedDataset(
                                id = '', 
                                name = '', 
                                column_id = '', 
                                column_name = '', ), 
                            join_type = 'inner', ), 
                        model_problem_type = 'regression', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListDataset(self):
        """Test ResourceListDataset"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
